@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import os, re
+import os, re, gzip, StringIO, zlib
 from urlparse import urlparse
 from PyQt4 import QtCore
 from PyQt4.QtNetwork import QNetworkRequest, QNetworkAccessManager, QNetworkProxy, QNetworkReply
@@ -11,7 +11,7 @@ from model.RideModel import RideModel, Ride
 
 class Extractor(QtCore.QObject):
    def __init__(self, id):
-      DebugLog("Extractor::Init")
+      DebugLog("Extractor::__init__")
       QtCore.QObject.__init__(self)
 
       self.url = ''
@@ -73,6 +73,7 @@ class Extractor(QtCore.QObject):
       if self.online and self.manager:
          request = QNetworkRequest( QtCore.QUrl(self.url) )
          request.setRawHeader("User-Agent", self.userAgent)
+         request.setRawHeader( "Accept-Encoding", "gzip, deflate" )
          reply = self.manager.get(request)
          self.connect(reply, QtCore.SIGNAL("downloadProgress(qint64, qint64)"), self.updateBar)
 
@@ -90,6 +91,21 @@ class Extractor(QtCore.QObject):
       error = reply.error()
 
       html = str(reply.readAll())
+      DebugLog("readData %d"%len(html))
+         
+      # handle compressed datas
+      if reply.hasRawHeader("Content-Encoding"):
+         encoding = reply.rawHeader("Content-Encoding")
+         DebugLog("encoding:%s"%encoding)
+         if encoding in ('gzip', 'x-gzip', 'deflate'):
+            if encoding == 'deflate':
+               html = StringIO.StringIO(zlib.decompress(html))
+            else:
+               try:  # Try except, it seems ratp.mobi returns gzip Content-Encoding, but not gzipped at all :-(
+                  html = gzip.GzipFile('', 'rb', 9, StringIO.StringIO(html)).read()
+               except Exception, e:
+                  DebugLog(str(e))
+            DebugLog("readData decoded %d"%len(html))
 
       # test d'erreur, en général, pas de connection internet
       if error != QNetworkReply.NoError:
