@@ -11,7 +11,7 @@ from model.RideModel import Ride
 class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
 
    def __init__(self):
-      DebugLog("TableParserRERratpMobi::Init")
+      DebugLog("TableParserRERratpMobi::__init__")
 
       HTMLParser.HTMLParser.__init__(self)
       self.Clear()
@@ -197,7 +197,7 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
 
 class ExtractorRERratp(TableParserRERratp):
    def __init__(self, ligne):
-      DebugLog("ExtractorRERratp::Init")
+      DebugLog("ExtractorRERratp::__init__")
 
       Extractor.__init__(self, ligne.id)
 
