@@ -13,7 +13,7 @@ from model.RideModel import Ride
 class TableParserTramway(Extractor, HTMLParser.HTMLParser):
 
    def __init__(self):
-      DebugLog("TableParserTramway::Init")
+      DebugLog("TableParserTramway::__init__")
 
       HTMLParser.HTMLParser.__init__(self)
       self.Clear()
@@ -135,7 +135,7 @@ class TableParserTramway(Extractor, HTMLParser.HTMLParser):
 
 class ExtractorTramway(TableParserTramway):
    def __init__(self, ligne):
-      DebugLog("ExtractorTramway::Init")
+      DebugLog("ExtractorTramway::__init__")
 
       Extractor.__init__(self, ligne.id)
 
