@@ -1,9 +1,9 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import   os
+import os
 from PyQt4 import QtCore
-from PyQt4.QtCore import QAbstractTableModel, Qt, QVariant
+from PyQt4.QtCore import Qt
 from utils.DebugLog import DebugLog
 from utils.TrainDb import  DbTrain, GareManager
 from utils.Config import TrainTrainConf, ConfFile, RidesConfig
@@ -13,11 +13,11 @@ from extractors.ExtractorBus import ExtractorBus
 from extractors.ExtractorRERratp import ExtractorRERratp
 from extractors.ExtractorTramway import ExtractorTramway
 
-class TrainTrainModel(QAbstractTableModel):
+class TrainTrainModel(QtCore.QObject):
    def __init__(self):
-      QAbstractTableModel.__init__(self)
-      DebugLog("TrainTrainModel::Init")
-
+      DebugLog("TrainTrainModel::__init__")
+      QtCore.QObject.__init__(self)
+      
       self.labels = ['Train', 'Heure', 'Destination', 'Voie']
 
       confDir = os.path.join(os.path.expanduser('~'),".traintrain")
@@ -96,7 +96,7 @@ class TrainTrainModel(QAbstractTableModel):
       DebugLog("TrainTrainModel::InitDatas")
       self.garesConf.ReadRides()
       self.rideList = dict()
-      self.reset()
+
       for ligne in self.garesConf.GetRides():
          self.CreateAndAddRide(ligne)
       DebugLog("initialized")
