@@ -16,7 +16,7 @@ class TrainTrainView(QtGui.QMainWindow):
    def __init__(self, argv, parent=None):
       QtGui.QMainWindow.__init__(self, parent)
 
-      DebugLog("TrainTrainView::Init")
+      DebugLog("TrainTrainView::__init__")
       self.offline = os.environ.has_key('OFFLINE')
 
       desktop = QtGui.QApplication.desktop()
